/* collection-view.c generated by valac 0.19.0.4-1540d, the Vala compiler
 * generated from collection-view.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <libgd/gd.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <cairo.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>


#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_COLLECTION_VIEW_TYPE_MODEL_COLUMNS (boxes_collection_view_model_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCategoryPrivate BoxesCategoryPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block10Data Block10Data;
typedef struct _Block11Data Block11Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
typedef struct _Block12Data Block12Data;

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionView {
	BoxesUI parent_instance;
	BoxesCollectionViewPrivate * priv;
	GdMainIconView* icon_view;
};

struct _BoxesCollectionViewClass {
	BoxesUIClass parent_class;
};

struct _BoxesCollectionViewPrivate {
	GtkClutterActor* gtkactor;
	BoxesCategory* _category;
	GtkListStore* model;
	GtkTreeModelFilter* model_filter;
	gchar* button_press_item_path;
};

typedef enum  {
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT = GD_MAIN_COLUMN_ICON,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE = GD_MAIN_COLUMN_PRIMARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO = GD_MAIN_COLUMN_SECONDARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED = GD_MAIN_COLUMN_SELECTED,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM = GD_MAIN_COLUMN_LAST,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST
} BoxesCollectionViewModelColumns;

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;

struct _BoxesCategory {
	GObject parent_instance;
	BoxesCategoryPrivate * priv;
	gchar* name;
	BoxesCategoryKind kind;
};

struct _BoxesCategoryClass {
	GObjectClass parent_class;
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 0
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block10Data {
	int _ref_count_;
	BoxesCollectionView * self;
	BoxesMachine* machine;
	GtkTreeIter iter;
	BoxesCollectionItem* item;
};

struct _Block11Data {
	int _ref_count_;
	BoxesCollectionView * self;
	GList* selected;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block12Data {
	int _ref_count_;
	BoxesCollectionView * self;
	BoxesSelectionCriteria selection;
};


static gpointer boxes_collection_view_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_category_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewPrivate))
enum  {
	BOXES_COLLECTION_VIEW_DUMMY_PROPERTY,
	BOXES_COLLECTION_VIEW_ACTOR,
	BOXES_COLLECTION_VIEW_CATEGORY,
	BOXES_COLLECTION_VIEW_VISIBLE
};
static GType boxes_collection_view_model_columns_get_type (void) G_GNUC_UNUSED;
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value);
static void boxes_collection_view_setup_view (BoxesCollectionView* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda54_ (BoxesCollectionView* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void ___lambda54__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
void boxes_collection_view_get_item_pos (BoxesCollectionView* self, BoxesCollectionItem* item, gfloat* x, gfloat* y);
static GtkTreePath* boxes_collection_view_get_path_for_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void boxes_collection_view_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void boxes_collection_view_update_item_visible (BoxesCollectionView* self, BoxesCollectionItem* item);
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value);
static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
static void __lambda56_ (Block10Data* _data10_);
static void ___lambda56__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda57_ (Block10Data* _data10_);
static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda58_ (Block10Data* _data10_);
static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda59_ (Block10Data* _data10_);
static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_actor_remove (ClutterActor* actor);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void block11_data_unref (void * _userdata_);
static gboolean __lambda60_ (Block11Data* _data11_, GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda60__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter);
static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path);
static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_collection_view_activate (BoxesCollectionView* self);
static gint __lambda33_ (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b);
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint ___lambda33__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void __lambda34_ (BoxesCollectionView* self);
static void ___lambda34__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self);
static void __lambda35_ (BoxesCollectionView* self);
static void ___lambda35__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static gboolean boxes_collection_view_on_button_press_event (BoxesCollectionView* self, GtkWidget* view, GdkEventButton* event);
static gboolean _boxes_collection_view_on_button_press_event_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static gboolean boxes_collection_view_on_button_release_event (BoxesCollectionView* self, GtkWidget* view, GdkEventButton* event);
static gboolean _boxes_collection_view_on_button_release_event_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate);
static void __lambda37_ (BoxesCollectionView* self, GtkIconView* view, GtkTreePath* path);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ___lambda37__gtk_icon_view_item_activated (GtkIconView* _sender, GtkTreePath* path, gpointer self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static gboolean boxes_collection_view_on_button_release_selection_mode (BoxesCollectionView* self, GdkEventButton* event, gboolean entered_mode, GtkTreePath* path);
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static gboolean __lambda61_ (Block12Data* _data12_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda61__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_set_visible (BoxesCollectionView* self, gboolean value);
static void boxes_collection_view_finalize (GObject* obj);
static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_selection_criteria_get_type (void) {
	static volatile gsize boxes_selection_criteria_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_criteria_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SELECTION_CRITERIA_ALL, "BOXES_SELECTION_CRITERIA_ALL", "all"}, {BOXES_SELECTION_CRITERIA_NONE, "BOXES_SELECTION_CRITERIA_NONE", "none"}, {BOXES_SELECTION_CRITERIA_RUNNING, "BOXES_SELECTION_CRITERIA_RUNNING", "running"}, {0, NULL, NULL}};
		GType boxes_selection_criteria_type_id;
		boxes_selection_criteria_type_id = g_enum_register_static ("BoxesSelectionCriteria", values);
		g_once_init_leave (&boxes_selection_criteria_type_id__volatile, boxes_selection_criteria_type_id);
	}
	return boxes_selection_criteria_type_id__volatile;
}


static GType boxes_collection_view_model_columns_get_type (void) {
	static volatile gsize boxes_collection_view_model_columns_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_model_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT", "screenshot"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE", "title"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO", "info"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED", "selected"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM", "item"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_collection_view_model_columns_type_id;
		boxes_collection_view_model_columns_type_id = g_enum_register_static ("BoxesCollectionViewModelColumns", values);
		g_once_init_leave (&boxes_collection_view_model_columns_type_id__volatile, boxes_collection_view_model_columns_type_id);
	}
	return boxes_collection_view_model_columns_type_id__volatile;
}


static void __lambda54_ (BoxesCollectionView* self) {
	GdMainIconView* _tmp0_;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	BoxesApp* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->icon_view;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = boxes_app_get_selection_mode (_tmp1_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _tmp2_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_generic_set_selection_mode ((GdMainViewGeneric*) _tmp0_, _tmp3_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_app;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = boxes_app_get_selection_mode (_tmp4_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp6_) {
#line 619 "collection-view.c"
		GdMainIconView* _tmp7_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = self->icon_view;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_generic_unselect_all ((GdMainViewGeneric*) _tmp7_);
#line 625 "collection-view.c"
	}
}


static void ___lambda54__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda54_ (self);
#line 633 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_construct (GType object_type) {
	BoxesCollectionView * self = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCategory* _tmp1_;
	BoxesCategory* _tmp2_;
	BoxesApp* _tmp3_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) boxes_ui_construct (object_type);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _ ("New and Recent");
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_category_new (_tmp0_, BOXES_CATEGORY_KIND_NEW);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_set_category (self, _tmp2_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_tmp2_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_view (self);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::selection-mode", (GCallback) ___lambda54__g_object_notify, self, 0);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self;
#line 663 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_new (void) {
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return boxes_collection_view_construct (BOXES_TYPE_COLLECTION_VIEW);
#line 670 "collection-view.c"
}


void boxes_collection_view_get_item_pos (BoxesCollectionView* self, BoxesCollectionItem* item, gfloat* x, gfloat* y) {
	gfloat _vala_x = 0.0F;
	gfloat _vala_y = 0.0F;
	GdkRectangle rect = {0};
	BoxesCollectionItem* _tmp0_;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreePath* path;
	GtkTreePath* _tmp2_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_path_for_item (self, _tmp0_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp1_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = path;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ != NULL) {
#line 696 "collection-view.c"
		GdMainIconView* _tmp3_;
		GtkTreePath* _tmp4_;
		GdkRectangle _tmp5_ = {0};
		GdkRectangle _tmp6_;
		gint _tmp7_;
		GdkRectangle _tmp8_;
		gint _tmp9_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = self->icon_view;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = path;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_get_cell_rect ((GtkIconView*) _tmp3_, _tmp4_, NULL, &_tmp5_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		rect = _tmp5_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = rect;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = _tmp6_.x;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_x = (gfloat) _tmp7_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp8_ = rect;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = _tmp8_.y;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_y = (gfloat) _tmp9_;
#line 724 "collection-view.c"
	} else {
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_x = 0.0f;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_y = 0.0f;
#line 730 "collection-view.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (x) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*x = _vala_x;
#line 738 "collection-view.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (y) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*y = _vala_y;
#line 744 "collection-view.c"
	}
}


static void boxes_collection_view_real_ui_state_changed (BoxesUI* base) {
	BoxesCollectionView * self;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	gint _tmp3_ = 0;
	BoxesUIState _tmp4_;
	BoxesUIState _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActor* _tmp7_;
	gint _tmp8_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == BOXES_UI_STATE_COLLECTION) {
#line 767 "collection-view.c"
		GdMainIconView* _tmp2_;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = self->icon_view;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_generic_unselect_all ((GdMainViewGeneric*) _tmp2_);
#line 773 "collection-view.c"
	}
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp4_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == BOXES_UI_STATE_COLLECTION) {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = 255;
#line 783 "collection-view.c"
	} else {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = 0;
#line 787 "collection-view.c"
	}
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _tmp6_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp3_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_fade_actor (_tmp7_, (guint) _tmp8_);
#line 797 "collection-view.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? g_object_ref (self) : NULL;
#line 804 "collection-view.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	for (i = 0; i < stack_length; i++) {
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return TRUE;
#line 816 "collection-view.c"
		}
	}
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return FALSE;
#line 821 "collection-view.c"
}


static void boxes_collection_view_update_item_visible (BoxesCollectionView* self, BoxesCollectionItem* item) {
	gboolean visible;
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp14_;
	ClutterActor* _tmp15_;
	ClutterActor* _tmp16_;
	gboolean _tmp17_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	visible = FALSE;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE)) {
#line 842 "collection-view.c"
		BoxesCollectionItem* _tmp1_;
		BoxesMachine* _tmp2_;
		BoxesMachine* machine;
		BoxesCategory* _tmp3_;
		BoxesCategory* _tmp4_;
		BoxesCategoryKind _tmp5_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp1_ = item;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp2_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = boxes_collection_view_get_category (self);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp3_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = _tmp4_->kind;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		switch (_tmp5_) {
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			case BOXES_CATEGORY_KIND_USER:
#line 865 "collection-view.c"
			{
				BoxesCategory* _tmp6_;
				BoxesCategory* _tmp7_;
				const gchar* _tmp8_;
				BoxesMachine* _tmp9_;
				BoxesBoxConfig* _tmp10_;
				gchar** _tmp11_;
				gint _tmp11__length1;
				gchar** _tmp12_;
				gint _tmp12__length1;
				gchar** _tmp13_;
				gint _tmp13__length1;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = boxes_collection_view_get_category (self);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = _tmp6_;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp8_ = _tmp7_->name;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = machine;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp10_ = _tmp9_->config;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = boxes_box_config_get_categories (_tmp10_, &_tmp11__length1);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12_ = _tmp11_;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12__length1 = _tmp11__length1;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13_ = _tmp12_;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13__length1 = _tmp12__length1;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				visible = _vala_string_array_contains (_tmp13_, _tmp12__length1, _tmp8_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				break;
#line 904 "collection-view.c"
			}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			case BOXES_CATEGORY_KIND_NEW:
#line 908 "collection-view.c"
			{
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				visible = TRUE;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				break;
#line 914 "collection-view.c"
			}
			default:
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 919 "collection-view.c"
		}
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 923 "collection-view.c"
	}
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = boxes_ui_get_actor ((BoxesUI*) _tmp14_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = _tmp15_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = visible;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set (_tmp16_, "visible", _tmp17_, NULL);
#line 935 "collection-view.c"
}


static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value) {
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((*length) == (*size)) {
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*array = g_renew (GIcon*, *array, (*size) + 1);
#line 946 "collection-view.c"
	}
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[(*length)++] = value;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[*length] = NULL;
#line 952 "collection-view.c"
}


static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* item = NULL;
	GIcon** _tmp0_ = NULL;
	GIcon** emblem_icons;
	gint emblem_icons_length1;
	gint _emblem_icons_size_;
	GtkListStore* _tmp1_;
	GtkTreeIter _tmp2_;
	BoxesCollectionItem* _tmp3_;
	BoxesMachine* _tmp4_;
	BoxesMachine* machine;
	BoxesMachine* _tmp5_;
	BoxesMachine* _tmp6_;
	GdkPixbuf* _tmp7_;
	GdkPixbuf* _tmp8_;
	GdkPixbuf* _tmp9_;
	GdkPixbuf* pixbuf;
	BoxesMachine* _tmp10_;
	BoxesBoxConfig* _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar** _tmp13_;
	gint _tmp13__length1;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gboolean _tmp15_;
	GIcon** _tmp18_;
	gint _tmp18__length1;
	GtkListStore* _tmp47_;
	GtkTreeIter _tmp48_;
	GdkPixbuf* _tmp49_;
	GdMainIconView* _tmp50_;
	GError * _inner_error_ = NULL;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = g_new0 (GIcon*, 0 + 1);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = _tmp0_;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons_length1 = 0;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_emblem_icons_size_ = emblem_icons_length1;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->model;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = *iter;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp1_, &_tmp2_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine = _tmp4_;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = machine;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_machine_get_pixbuf (_tmp6_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp7_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf = _tmp9_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = machine;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _tmp10_->config;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = boxes_box_config_get_categories (_tmp11_, &_tmp12__length1);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _tmp12_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13__length1 = _tmp12__length1;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _tmp13_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14__length1 = _tmp13__length1;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _vala_string_array_contains (_tmp14_, _tmp13__length1, "favorite");
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_free), NULL);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp15_) {
#line 1047 "collection-view.c"
		GIcon** _tmp16_;
		gint _tmp16__length1;
		GIcon* _tmp17_ = NULL;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16_ = emblem_icons;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16__length1 = emblem_icons_length1;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp17_ = boxes_create_symbolic_emblem ("emblem-favorite");
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_array_add1 (&emblem_icons, &emblem_icons_length1, &_emblem_icons_size_, _tmp17_);
#line 1059 "collection-view.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = emblem_icons;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18__length1 = emblem_icons_length1;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp18__length1 > 0) {
#line 1067 "collection-view.c"
		GdkPixbuf* _tmp19_;
		GEmblemedIcon* _tmp20_;
		GEmblemedIcon* emblemed_icon;
		GIcon** _tmp21_;
		gint _tmp21__length1;
		GtkIconTheme* _tmp27_ = NULL;
		GtkIconTheme* _tmp28_;
		GtkIconTheme* theme;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp19_ = pixbuf;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp20_ = (GEmblemedIcon*) g_emblemed_icon_new ((GIcon*) _tmp19_, NULL);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		emblemed_icon = _tmp20_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = emblem_icons;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21__length1 = emblem_icons_length1;
#line 1086 "collection-view.c"
		{
			GIcon** emblem_icon_collection = NULL;
			gint emblem_icon_collection_length1 = 0;
			gint _emblem_icon_collection_size_ = 0;
			gint emblem_icon_it = 0;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection = _tmp21_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection_length1 = _tmp21__length1;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			for (emblem_icon_it = 0; emblem_icon_it < _tmp21__length1; emblem_icon_it = emblem_icon_it + 1) {
#line 1098 "collection-view.c"
				GIcon* _tmp22_;
				GIcon* emblem_icon = NULL;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp22_ = _g_object_ref0 (emblem_icon_collection[emblem_icon_it]);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				emblem_icon = _tmp22_;
#line 1105 "collection-view.c"
				{
					GEmblemedIcon* _tmp23_;
					GIcon* _tmp24_;
					GEmblem* _tmp25_;
					GEmblem* _tmp26_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp23_ = emblemed_icon;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp24_ = emblem_icon;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp25_ = g_emblem_new (_tmp24_);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp26_ = _tmp25_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					g_emblemed_icon_add_emblem (_tmp23_, _tmp26_);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (_tmp26_);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (emblem_icon);
#line 1125 "collection-view.c"
				}
			}
		}
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = gtk_icon_theme_get_default ();
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp28_ = _g_object_ref0 (_tmp27_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		theme = _tmp28_;
#line 1135 "collection-view.c"
		{
			GdkPixbuf* _tmp29_;
			gint _tmp30_;
			gint _tmp31_;
			GdkPixbuf* _tmp32_;
			gint _tmp33_;
			gint _tmp34_;
			gint _tmp35_ = 0;
			gint size;
			GtkIconTheme* _tmp36_;
			GEmblemedIcon* _tmp37_;
			gint _tmp38_;
			GtkIconInfo* _tmp39_ = NULL;
			GtkIconInfo* icon_info;
			GtkIconInfo* _tmp40_;
			GdkPixbuf* _tmp41_ = NULL;
			GdkPixbuf* _tmp42_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp29_ = pixbuf;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp30_ = gdk_pixbuf_get_width (_tmp29_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp31_ = _tmp30_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp32_ = pixbuf;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp33_ = gdk_pixbuf_get_height (_tmp32_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp34_ = _tmp33_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp35_ = MAX (_tmp31_, _tmp34_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			size = _tmp35_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp36_ = theme;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp37_ = emblemed_icon;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp38_ = size;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp39_ = gtk_icon_theme_lookup_by_gicon (_tmp36_, (GIcon*) _tmp37_, _tmp38_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			icon_info = _tmp39_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp40_ = icon_info;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp41_ = gtk_icon_info_load_icon (_tmp40_, &_inner_error_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp42_ = _tmp41_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_inner_error_ != NULL) {
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_g_object_unref0 (icon_info);
#line 1189 "collection-view.c"
				goto __catch8_g_error;
			}
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			pixbuf = _tmp42_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (icon_info);
#line 1198 "collection-view.c"
		}
		goto __finally8;
		__catch8_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp43_;
			const gchar* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_error_ = _inner_error_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_inner_error_ = NULL;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp43_ = _error_;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp44_ = _tmp43_->message;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp45_ = g_strconcat ("Unable to render the emblem: ", _tmp44_, NULL);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp46_ = _tmp45_;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_warning ("collection-view.vala:118: %s", _tmp46_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_free0 (_tmp46_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_error_free0 (_error_);
#line 1226 "collection-view.c"
		}
		__finally8:
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (_inner_error_ != NULL) {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (theme);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (emblemed_icon);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (machine);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_clear_error (&_inner_error_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return;
#line 1249 "collection-view.c"
		}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (theme);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (emblemed_icon);
#line 1255 "collection-view.c"
	}
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp47_ = self->priv->model;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp48_ = *iter;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp49_ = pixbuf;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp47_, &_tmp48_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, _tmp49_, -1);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp50_ = self->icon_view;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp50_);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (pixbuf);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (machine);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 1277 "collection-view.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return dup;
#line 1289 "collection-view.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 1296 "collection-view.c"
}


static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_;
	GtkTreeIter _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	GtkListStore* _tmp9_;
	GtkTreeIter _tmp10_;
	GtkListStore* _tmp11_;
	GtkTreeIter _tmp12_;
	BoxesCollectionItem* _tmp13_;
	GtkTreeIter _tmp14_;
	BoxesCollectionItem* _tmp15_;
	GtkTreeIter _tmp16_;
	GtkTreeIter* _tmp17_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (title != NULL);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp1_;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = title;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = info;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ != NULL) {
#line 1341 "collection-view.c"
		GtkListStore* _tmp6_;
		GtkTreeIter _tmp7_;
		const gchar* _tmp8_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = self->priv->model;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = iter;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp8_ = info;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp6_, &_tmp7_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp8_, -1);
#line 1353 "collection-view.c"
	}
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = self->priv->model;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = iter;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp9_, &_tmp10_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = self->priv->model;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = iter;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = item;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp11_, &_tmp12_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, _tmp13_, -1);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = iter;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp14_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = item;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = iter;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = __gtk_tree_iter_dup0 (&_tmp16_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp15_, "iter", _tmp17_, g_free);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	*result = iter;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return;
#line 1385 "collection-view.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data10_;
#line 1394 "collection-view.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 1403 "collection-view.c"
		BoxesCollectionView * self;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data10_->self;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data10_->machine);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data10_->item);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block10Data, _data10_);
#line 1415 "collection-view.c"
	}
}


static void __lambda56_ (Block10Data* _data10_) {
	BoxesCollectionView * self;
	GtkTreeIter _tmp0_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data10_->iter;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1429 "collection-view.c"
}


static void ___lambda56__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda56_ (self);
#line 1436 "collection-view.c"
}


static void __lambda57_ (Block10Data* _data10_) {
	BoxesCollectionView * self;
	GtkTreeIter _tmp0_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data10_->iter;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1449 "collection-view.c"
}


static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda57_ (self);
#line 1456 "collection-view.c"
}


static void __lambda58_ (Block10Data* _data10_) {
	BoxesCollectionView * self;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	BoxesCollectionItem* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GdMainIconView* _tmp5_;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data10_->iter;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->item;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_collection_item_get_name (_tmp2_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->icon_view;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp5_);
#line 1486 "collection-view.c"
}


static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda58_ (self);
#line 1493 "collection-view.c"
}


static void __lambda59_ (Block10Data* _data10_) {
	BoxesCollectionView * self;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	BoxesMachine* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GdMainIconView* _tmp5_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data10_->iter;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->machine;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_machine_get_info (_tmp2_);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp4_, -1);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->icon_view;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp5_);
#line 1523 "collection-view.c"
}


static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda59_ (self);
#line 1530 "collection-view.c"
}


void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	Block10Data* _data10_;
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesMachine* _tmp3_;
	BoxesMachine* _tmp4_;
	BoxesMachine* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	BoxesMachine* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	BoxesCollectionItem* _tmp13_;
	GtkTreeIter _tmp14_ = {0};
	BoxesMachine* _tmp15_;
	gulong _tmp16_ = 0UL;
	gulong pixbuf_id;
	BoxesCollectionItem* _tmp17_;
	gulong _tmp18_;
	BoxesMachine* _tmp19_;
	BoxesBoxConfig* _tmp20_;
	gulong _tmp21_ = 0UL;
	gulong categories_id;
	BoxesCollectionItem* _tmp22_;
	gulong _tmp23_;
	BoxesCollectionItem* _tmp24_;
	gulong _tmp25_ = 0UL;
	gulong name_id;
	BoxesCollectionItem* _tmp26_;
	gulong _tmp27_;
	BoxesMachine* _tmp28_;
	gulong _tmp29_ = 0UL;
	gulong info_id;
	BoxesCollectionItem* _tmp30_;
	gulong _tmp31_;
	BoxesCollectionItem* _tmp32_;
	BoxesApp* _tmp33_;
	BoxesUIState _tmp34_;
	BoxesUIState _tmp35_;
	BoxesCollectionItem* _tmp36_;
	ClutterActor* _tmp37_;
	ClutterActor* _tmp38_;
	BoxesCollectionItem* _tmp39_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->_ref_count_ = 1;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->self = g_object_ref (self);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data10_->item);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->item = _tmp1_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->item;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->machine = _tmp3_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data10_->machine;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 1606 "collection-view.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = g_strdup_printf ("Cannot add item %p", &_data10_->item);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_warning ("collection-view.vala:148: %s", _tmp6_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (_tmp6_);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block10_data_unref (_data10_);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data10_ = NULL;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1623 "collection-view.c"
	}
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data10_->machine;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp7_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = _data10_->machine;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = boxes_machine_get_info (_tmp10_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = _tmp11_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _data10_->item;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_append (self, _tmp9_, _tmp12_, _tmp13_, &_tmp14_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->iter = _tmp14_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _data10_->machine;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = g_signal_connect_data ((GObject*) _tmp15_, "notify::pixbuf", (GCallback) ___lambda56__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = _tmp16_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _data10_->item;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = pixbuf_id;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp17_, "pixbuf_id", (gpointer) ((guintptr) _tmp18_), NULL);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = _data10_->machine;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_->config;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_signal_connect_data ((GObject*) _tmp20_, "notify::categories", (GCallback) ___lambda57__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	categories_id = _tmp21_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = _data10_->item;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = categories_id;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp22_, "categories_id", (gpointer) ((guintptr) _tmp23_), NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = _data10_->item;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = g_signal_connect_data ((GObject*) _tmp24_, "notify::name", (GCallback) ___lambda58__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = _tmp25_;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = _data10_->item;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = name_id;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp26_, "name_id", (gpointer) ((guintptr) _tmp27_), NULL);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = _data10_->machine;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = g_signal_connect_data ((GObject*) _tmp28_, "notify::info", (GCallback) ___lambda59__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = _tmp29_;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = _data10_->item;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp31_ = info_id;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp30_, "info_id", (gpointer) ((guintptr) _tmp31_), NULL);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp32_ = _data10_->item;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp33_ = boxes_app_app;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp34_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp33_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp35_ = _tmp34_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp32_, _tmp35_);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp36_ = _data10_->item;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp37_ = boxes_ui_get_actor ((BoxesUI*) _tmp36_);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp38_ = _tmp37_;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_actor_remove (_tmp38_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp39_ = _data10_->item;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_item_visible (self, _tmp39_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block10_data_unref (_data10_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_ = NULL;
#line 1719 "collection-view.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data11_;
#line 1728 "collection-view.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1735 "collection-view.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_free (self);
#line 1744 "collection-view.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 1753 "collection-view.c"
		BoxesCollectionView * self;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data11_->self;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		__g_list_free__g_object_unref0_0 (_data11_->selected);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block11Data, _data11_);
#line 1763 "collection-view.c"
	}
}


static gboolean __lambda60_ (Block11Data* _data11_, GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesCollectionView * self;
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	gboolean is_selected = FALSE;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
	gboolean _tmp5_;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = model;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &is_selected, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = is_selected;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_) {
#line 1796 "collection-view.c"
		BoxesCollectionItem* _tmp4_;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1802 "collection-view.c"
	} else {
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 1806 "collection-view.c"
	}
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp2_;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_) {
#line 1812 "collection-view.c"
		BoxesCollectionItem* _tmp6_;
		BoxesCollectionItem* _tmp7_;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data11_->selected = g_list_append (_data11_->selected, _tmp7_);
#line 1821 "collection-view.c"
	}
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1829 "collection-view.c"
}


static gboolean ___lambda60__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda60_ (self, model, path, iter);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1838 "collection-view.c"
}


GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self) {
	GList* result = NULL;
	Block11Data* _data11_;
	GtkListStore* _tmp0_;
	GList* _tmp1_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->_ref_count_ = 1;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->self = g_object_ref (self);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->selected = NULL;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp0_, ___lambda60__gtk_tree_model_foreach_func, _data11_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data11_->selected;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->selected = NULL;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp1_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block11_data_unref (_data11_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = NULL;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1873 "collection-view.c"
}


void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_;
	GtkTreeIter* iter;
	GtkTreeIter* _tmp3_;
	GtkListStore* _tmp4_;
	GtkTreeIter* _tmp5_;
	GtkTreeIter _tmp6_;
	BoxesCollectionItem* _tmp7_;
	BoxesCollectionItem* _tmp8_;
	gconstpointer _tmp9_ = NULL;
	gulong pixbuf_id;
	BoxesCollectionItem* _tmp10_;
	gulong _tmp11_;
	BoxesCollectionItem* _tmp12_;
	gconstpointer _tmp13_ = NULL;
	gulong name_id;
	BoxesCollectionItem* _tmp14_;
	gulong _tmp15_;
	BoxesCollectionItem* _tmp16_;
	gconstpointer _tmp17_ = NULL;
	gulong info_id;
	BoxesCollectionItem* _tmp18_;
	gulong _tmp19_;
	BoxesCollectionItem* _tmp20_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_debug ("collection-view.vala:207: item not in view or already removed");
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1925 "collection-view.c"
	}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = *_tmp5_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_remove (_tmp4_, &_tmp6_);
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp7_, "iter", NULL, g_free);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = g_object_get_data ((GObject*) _tmp8_, "pixbuf_id");
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = (gulong) ((guintptr) _tmp9_);
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = item;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = pixbuf_id;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = item;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = g_object_get_data ((GObject*) _tmp12_, "name_id");
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = (gulong) ((guintptr) _tmp13_);
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = name_id;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = item;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = g_object_get_data ((GObject*) _tmp16_, "info_id");
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = (gulong) ((guintptr) _tmp17_);
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = info_id;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp18_, _tmp19_);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp20_) : NULL) != NULL) {
#line 1979 "collection-view.c"
		BoxesCollectionItem* _tmp21_;
		BoxesMachine* _tmp22_;
		BoxesMachine* machine;
		BoxesCollectionItem* _tmp23_;
		gconstpointer _tmp24_ = NULL;
		gulong categories_id;
		BoxesMachine* _tmp25_;
		BoxesBoxConfig* _tmp26_;
		gulong _tmp27_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = item;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp21_) : NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp22_;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp23_ = item;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp24_ = g_object_get_data ((GObject*) _tmp23_, "categories_id");
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		categories_id = (gulong) ((guintptr) _tmp24_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp25_ = machine;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp26_ = _tmp25_->config;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = categories_id;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp26_, _tmp27_);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 2011 "collection-view.c"
	}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 2015 "collection-view.c"
}


static GtkTreePath* boxes_collection_view_get_path_for_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	GtkTreePath* result = NULL;
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_;
	GtkTreeIter* iter;
	GtkTreeIter* _tmp3_;
	GtkTreeIter filter_iter = {0};
	GtkTreeModelFilter* _tmp4_;
	GtkTreeIter* _tmp5_;
	GtkTreeIter _tmp6_ = {0};
	GtkTreeIter _tmp7_;
	gboolean _tmp8_ = FALSE;
	GtkTreeModelFilter* _tmp9_;
	GtkTreeIter _tmp10_;
	GtkTreePath* _tmp11_ = NULL;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = NULL;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2057 "collection-view.c"
	}
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model_filter;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp5_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = gtk_tree_model_filter_convert_child_iter_to_iter (_tmp4_, &_tmp6_, &_tmp7_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp6_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp8_) {
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = NULL;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2077 "collection-view.c"
	}
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = self->priv->model_filter;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = filter_iter;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp9_, &_tmp10_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp11_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2091 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* result = NULL;
	GValue value = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GValue _tmp2_ = {0};
	GValue _tmp3_;
	BoxesCollectionItem* _tmp4_;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_value ((GtkTreeModel*) _tmp0_, &_tmp1_, (gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &_tmp2_);
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	value = _tmp2_;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = value;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp4_;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2127 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	BoxesCollectionItem* result = NULL;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_;
	GtkTreeIter _tmp4_;
	GtkTreeIter _tmp5_ = {0};
	GtkTreeIter _tmp6_;
	BoxesCollectionItem* _tmp7_ = NULL;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model_filter;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = filter_iter;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp5_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_collection_view_get_item_for_iter (self, &_tmp6_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp7_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2171 "collection-view.c"
}


static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	GtkTreeIter _tmp0_;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* item;
	BoxesCollectionItem* _tmp2_;
	BoxesApp* _tmp3_;
	BoxesCollectionFilter* _tmp4_;
	BoxesCollectionItem* _tmp5_;
	gboolean _tmp6_ = FALSE;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_iter (self, &_tmp0_);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2207 "collection-view.c"
	}
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_->filter;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_collection_filter_filter (_tmp4_, _tmp5_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp6_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2223 "collection-view.c"
}


void boxes_collection_view_refilter (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_refilter (_tmp0_);
#line 2235 "collection-view.c"
}


void boxes_collection_view_activate (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_;
	gint _tmp1_ = 0;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp0_, NULL);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == 1) {
#line 2250 "collection-view.c"
		GtkTreePath* _tmp2_;
		GtkTreePath* path;
		GdMainIconView* _tmp3_;
		GtkTreePath* _tmp4_;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = gtk_tree_path_new_from_string ("0");
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		path = _tmp2_;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = self->icon_view;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = path;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_item_activated ((GtkIconView*) _tmp3_, _tmp4_);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 2267 "collection-view.c"
	}
}


static gint __lambda33_ (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	BoxesCollectionItem* item_a = NULL;
	BoxesCollectionItem* item_b = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeModel* _tmp2_;
	GtkTreeIter _tmp3_;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionItem* _tmp5_;
	gboolean _tmp7_;
	BoxesCollectionItem* _tmp8_;
	BoxesCollectionItem* _tmp9_;
	gint _tmp10_ = 0;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, 0);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = model;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *a;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_a, -1);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = model;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *b;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_b, -1);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item_a;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == NULL) {
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = TRUE;
#line 2310 "collection-view.c"
	} else {
		BoxesCollectionItem* _tmp6_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item_b;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp6_ == NULL;
#line 2317 "collection-view.c"
	}
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _tmp4_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp7_) {
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = 0;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_b);
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_a);
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2331 "collection-view.c"
	}
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item_a;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = item_b;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = boxes_collection_item_compare (_tmp8_, _tmp9_);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp10_;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_b);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_a);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2347 "collection-view.c"
}


static gint ___lambda33__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = __lambda33_ (self, model, a, b);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2356 "collection-view.c"
}


static void __lambda34_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2366 "collection-view.c"
}


static void ___lambda34__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self) {
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda34_ (self);
#line 2373 "collection-view.c"
}


static void __lambda35_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2383 "collection-view.c"
}


static void ___lambda35__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda35_ (self);
#line 2390 "collection-view.c"
}


static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = boxes_collection_view_model_visible (self, model, iter);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2399 "collection-view.c"
}


static gboolean _boxes_collection_view_on_button_press_event_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_button_press_event (self, _sender, event);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2408 "collection-view.c"
}


static gboolean _boxes_collection_view_on_button_release_event_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_button_release_event (self, _sender, event);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2417 "collection-view.c"
}


static void __lambda37_ (BoxesCollectionView* self, GtkIconView* view, GtkTreePath* path) {
	GtkTreePath* _tmp0_;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* item;
	BoxesApp* _tmp2_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (view != NULL);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (path != NULL);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = boxes_app_app;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_select_item (_tmp2_, item);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 2442 "collection-view.c"
}


static void ___lambda37__gtk_icon_view_item_activated (GtkIconView* _sender, GtkTreePath* path, gpointer self) {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda37_ (self, _sender, path);
#line 2449 "collection-view.c"
}


static void boxes_collection_view_setup_view (BoxesCollectionView* self) {
	GtkListStore* _tmp0_;
	GtkListStore* _tmp1_;
	GtkListStore* _tmp2_;
	GtkListStore* _tmp3_;
	GtkListStore* _tmp4_;
	GtkListStore* _tmp5_;
	GtkTreeModelFilter* _tmp6_;
	GtkTreeModelFilter* _tmp7_;
	GdMainIconView* _tmp8_;
	GdMainIconView* _tmp9_;
	GtkTreeModelFilter* _tmp10_;
	GdMainIconView* _tmp11_;
	GtkStyleContext* _tmp12_ = NULL;
	GdMainIconView* _tmp13_;
	GdMainIconView* _tmp14_;
	GdMainIconView* _tmp15_;
	GdMainIconView* _tmp16_;
	GtkScrolledWindow* _tmp17_;
	GtkScrolledWindow* scrolled_window;
	GdMainIconView* _tmp18_;
	GtkStyleContext* _tmp19_ = NULL;
	GtkClutterActor* _tmp20_;
	GtkClutterActor* _tmp21_;
	GtkWidget* _tmp22_ = NULL;
	GtkStyleContext* _tmp23_ = NULL;
	GtkClutterActor* _tmp24_;
	GtkClutterActor* _tmp25_;
	GtkClutterActor* _tmp26_;
	GtkClutterActor* _tmp27_;
	GtkClutterActor* _tmp28_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = gtk_list_store_new ((gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_LONG, G_TYPE_BOOLEAN, BOXES_TYPE_COLLECTION_ITEM);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model = _tmp0_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->model;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp1_, ___lambda33__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp2_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp3_, "row-deleted", (GCallback) ___lambda34__gtk_tree_model_row_deleted, self, 0);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp4_, "row-inserted", (GCallback) ___lambda35__gtk_tree_model_row_inserted, self, 0);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->model;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model_filter = _tmp6_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model_filter;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_set_visible_func (_tmp7_, _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = (GdMainIconView*) gd_main_icon_view_new ();
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_ref_sink (_tmp8_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->icon_view);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->icon_view = _tmp8_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = self->icon_view;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = self->priv->model_filter;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_generic_set_model ((GdMainViewGeneric*) _tmp9_, (GtkTreeModel*) _tmp10_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = self->icon_view;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp12_, "boxes-icon-view");
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = self->icon_view;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) _tmp13_, "button-press-event", (GCallback) _boxes_collection_view_on_button_press_event_gtk_widget_button_press_event, self, 0);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->icon_view;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) _tmp14_, "button-release-event", (GCallback) _boxes_collection_view_on_button_release_event_gtk_widget_button_release_event, self, 0);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = self->icon_view;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_icon_view_activate_on_single_click ((GtkIconView*) _tmp15_, TRUE);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->icon_view;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkIconView*) _tmp16_, "item-activated", (GCallback) ___lambda37__gtk_icon_view_item_activated, self, 0);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_ref_sink (_tmp17_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	scrolled_window = _tmp17_;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = self->icon_view;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_container_add ((GtkContainer*) scrolled_window, (GtkWidget*) _tmp18_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_show_all ((GtkWidget*) scrolled_window);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_scrolled_window_set_shadow_type (scrolled_window, GTK_SHADOW_IN);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = gtk_widget_get_style_context ((GtkWidget*) scrolled_window);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp19_, "documents-scrolledwin");
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) scrolled_window);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_ref_sink (_tmp20_);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->gtkactor);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->gtkactor = _tmp20_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = self->priv->gtkactor;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = gtk_clutter_actor_get_widget (_tmp21_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = gtk_widget_get_style_context (_tmp22_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp23_, "boxes-bg");
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = self->priv->gtkactor;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp24_, "collection-view");
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = self->priv->gtkactor;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp25_, CLUTTER_ACTOR_ALIGN_FILL);
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = self->priv->gtkactor;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp26_, CLUTTER_ACTOR_ALIGN_FILL);
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = self->priv->gtkactor;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp27_, TRUE);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = self->priv->gtkactor;
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp28_, TRUE);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (scrolled_window);
#line 2612 "collection-view.c"
}


static gboolean boxes_collection_view_on_button_press_event (BoxesCollectionView* self, GtkWidget* view, GdkEventButton* event) {
	gboolean result = FALSE;
	GdMainIconView* _tmp0_;
	GdkEventButton _tmp1_;
	gdouble _tmp2_;
	GdkEventButton _tmp3_;
	gdouble _tmp4_;
	GtkTreePath* _tmp5_ = NULL;
	GtkTreePath* path;
	GtkTreePath* _tmp6_;
	GtkTreePath* _tmp7_;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_;
	GtkTreePath* _tmp10_;
	BoxesCollectionItem* _tmp11_ = NULL;
	BoxesCollectionItem* item;
	BoxesCollectionItem* _tmp12_;
	gboolean found;
	gboolean _tmp13_;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (view != NULL, FALSE);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->icon_view;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *event;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_.x;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *event;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_.y;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = gd_main_view_generic_get_path_at_pos ((GdMainViewGeneric*) _tmp0_, (gint) _tmp2_, (gint) _tmp4_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp5_;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = path;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp6_ == NULL) {
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2665 "collection-view.c"
	}
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = path;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = gtk_tree_path_to_string (_tmp7_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (self->priv->button_press_item_path);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->button_press_item_path = _tmp9_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = path;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = boxes_collection_view_get_item_for_path (self, _tmp10_);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp11_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = item;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	found = _tmp12_ != NULL;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = found;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = !_tmp13_;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2697 "collection-view.c"
}


static gboolean boxes_collection_view_on_button_release_event (BoxesCollectionView* self, GtkWidget* view, GdkEventButton* event) {
	gboolean result = FALSE;
	GdkEventButton _tmp0_;
	GdkEventType _tmp1_;
	GdMainIconView* _tmp2_;
	GdkEventButton _tmp3_;
	gdouble _tmp4_;
	GdkEventButton _tmp5_;
	gdouble _tmp6_;
	GtkTreePath* _tmp7_ = NULL;
	GtkTreePath* path;
	gboolean same_item;
	GtkTreePath* _tmp8_;
	gboolean _tmp14_;
	gboolean entered_mode;
	BoxesApp* _tmp15_;
	gboolean _tmp16_;
	gboolean _tmp17_;
	BoxesApp* _tmp29_;
	gboolean _tmp30_;
	gboolean _tmp31_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (view != NULL, FALSE);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *event;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_.type;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ != GDK_BUTTON_RELEASE) {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = TRUE;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2738 "collection-view.c"
	}
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->icon_view;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *event;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_.x;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = *event;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_.y;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = gd_main_view_generic_get_path_at_pos ((GdMainViewGeneric*) _tmp2_, (gint) _tmp4_, (gint) _tmp6_);
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp7_;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	same_item = FALSE;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = path;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp8_ != NULL) {
#line 2760 "collection-view.c"
		GtkTreePath* _tmp9_;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_;
		gchar* button_release_item_path;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = path;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp10_ = gtk_tree_path_to_string (_tmp9_);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		button_release_item_path = _tmp11_;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = self->priv->button_press_item_path;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = button_release_item_path;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		same_item = g_strcmp0 (_tmp12_, _tmp13_) == 0;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (button_release_item_path);
#line 2783 "collection-view.c"
	}
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (self->priv->button_press_item_path);
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->button_press_item_path = NULL;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = same_item;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp14_) {
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2799 "collection-view.c"
	}
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	entered_mode = FALSE;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = boxes_app_app;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = boxes_app_get_selection_mode (_tmp15_);
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _tmp16_;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp17_) {
#line 2811 "collection-view.c"
		gboolean _tmp18_ = FALSE;
		GdkEventButton _tmp19_;
		guint _tmp20_;
		gboolean _tmp27_;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp19_ = *event;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp20_ = _tmp19_.button;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (_tmp20_ == ((guint) 3)) {
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp18_ = TRUE;
#line 2824 "collection-view.c"
		} else {
			gboolean _tmp21_ = FALSE;
			GdkEventButton _tmp22_;
			guint _tmp23_;
			gboolean _tmp26_;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp22_ = *event;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp23_ = _tmp22_.button;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp23_ == ((guint) 1)) {
#line 2836 "collection-view.c"
				GdkEventButton _tmp24_;
				GdkModifierType _tmp25_;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp24_ = *event;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp25_ = _tmp24_.state;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp21_ = (_tmp25_ & GDK_CONTROL_MASK) == GDK_CONTROL_MASK;
#line 2845 "collection-view.c"
			} else {
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp21_ = FALSE;
#line 2849 "collection-view.c"
			}
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp26_ = _tmp21_;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp18_ = _tmp26_;
#line 2855 "collection-view.c"
		}
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = _tmp18_;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (_tmp27_) {
#line 2861 "collection-view.c"
			BoxesApp* _tmp28_;
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp28_ = boxes_app_app;
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			boxes_app_set_selection_mode (_tmp28_, TRUE);
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			entered_mode = TRUE;
#line 2869 "collection-view.c"
		}
	}
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = boxes_app_app;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = boxes_app_get_selection_mode (_tmp29_);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp31_ = _tmp30_;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp31_) {
#line 2880 "collection-view.c"
		GdkEventButton _tmp32_;
		gboolean _tmp33_;
		GtkTreePath* _tmp34_;
		gboolean _tmp35_ = FALSE;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp32_ = *event;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp33_ = entered_mode;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp34_ = path;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp35_ = boxes_collection_view_on_button_release_selection_mode (self, &_tmp32_, _tmp33_, _tmp34_);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = _tmp35_;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2899 "collection-view.c"
	}
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2907 "collection-view.c"
}


static gboolean boxes_collection_view_on_button_release_selection_mode (BoxesCollectionView* self, GdkEventButton* event, gboolean entered_mode, GtkTreePath* path) {
	gboolean result = FALSE;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_ = FALSE;
	GtkTreeModelFilter* _tmp4_;
	GtkTreeIter _tmp5_;
	GtkTreeIter _tmp6_ = {0};
	gboolean selected = FALSE;
	GtkListStore* _tmp7_;
	GtkTreeIter _tmp8_;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_;
	gboolean _tmp12_;
	GdMainIconView* _tmp18_;
	BoxesApp* _tmp19_;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp3_) {
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2950 "collection-view.c"
	}
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model_filter;
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = filter_iter;
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp4_, &_tmp6_, &_tmp5_);
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp6_;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = iter;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp7_, &_tmp8_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &selected, -1);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = selected;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp10_) {
#line 2970 "collection-view.c"
		gboolean _tmp11_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = entered_mode;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = !_tmp11_;
#line 2976 "collection-view.c"
	} else {
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = FALSE;
#line 2980 "collection-view.c"
	}
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = _tmp9_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp12_) {
#line 2986 "collection-view.c"
		GtkListStore* _tmp13_;
		GtkTreeIter _tmp14_;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = self->priv->model;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp14_ = iter;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp13_, &_tmp14_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 2995 "collection-view.c"
	} else {
		gboolean _tmp15_;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp15_ = selected;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (!_tmp15_) {
#line 3002 "collection-view.c"
			GtkListStore* _tmp16_;
			GtkTreeIter _tmp17_;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp16_ = self->priv->model;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp17_ = iter;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			gtk_list_store_set (_tmp16_, &_tmp17_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, TRUE, -1);
#line 3011 "collection-view.c"
		}
	}
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = self->icon_view;
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp18_);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = boxes_app_app;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp19_, "selected-items");
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3026 "collection-view.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data12_;
#line 3035 "collection-view.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 3044 "collection-view.c"
		BoxesCollectionView * self;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data12_->self;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block12Data, _data12_);
#line 3052 "collection-view.c"
	}
}


static gboolean __lambda61_ (Block12Data* _data12_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter) {
	BoxesCollectionView * self;
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean selected = FALSE;
	BoxesSelectionCriteria _tmp3_;
	GtkListStore* _tmp14_;
	GtkTreeIter _tmp15_;
	gboolean _tmp16_;
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data12_->self;
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_model != NULL, FALSE);
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_path != NULL, FALSE);
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_iter != NULL, FALSE);
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *filter_iter;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp0_, &_tmp2_, &_tmp1_);
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data12_->selection;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (_tmp3_) {
#line 3089 "collection-view.c"
		default:
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_ALL:
#line 3093 "collection-view.c"
		{
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = TRUE;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 3099 "collection-view.c"
		}
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_NONE:
#line 3103 "collection-view.c"
		{
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = FALSE;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 3109 "collection-view.c"
		}
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_RUNNING:
#line 3113 "collection-view.c"
		{
			BoxesCollectionItem* item = NULL;
			GtkListStore* _tmp4_;
			GtkTreeIter _tmp5_;
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
			BoxesCollectionItem* _tmp8_;
			gboolean _tmp10_;
			gboolean _tmp13_;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp4_ = self->priv->model;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp5_ = iter;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp8_ = item;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp8_ != NULL) {
#line 3133 "collection-view.c"
				BoxesCollectionItem* _tmp9_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = item;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE);
#line 3139 "collection-view.c"
			} else {
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = FALSE;
#line 3143 "collection-view.c"
			}
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp10_ = _tmp7_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp10_) {
#line 3149 "collection-view.c"
				BoxesCollectionItem* _tmp11_;
				gboolean _tmp12_ = FALSE;
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = item;
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12_ = boxes_machine_is_running (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp11_) : NULL);
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = _tmp12_;
#line 3158 "collection-view.c"
			} else {
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = FALSE;
#line 3162 "collection-view.c"
			}
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp13_ = _tmp6_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = _tmp13_;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 3172 "collection-view.c"
		}
	}
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->model;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = selected;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, _tmp16_, -1);
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3187 "collection-view.c"
}


static gboolean ___lambda61__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda61_ (self, model, path, iter);
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3196 "collection-view.c"
}


void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection) {
	Block12Data* _data12_;
	BoxesSelectionCriteria _tmp0_;
	BoxesApp* _tmp1_;
	GtkTreeModelFilter* _tmp2_;
	GdMainIconView* _tmp3_;
	BoxesApp* _tmp4_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->_ref_count_ = 1;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->self = g_object_ref (self);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = selection;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->selection = _tmp0_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_set_selection_mode (_tmp1_, TRUE);
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model_filter;
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda61__gtk_tree_model_foreach_func, _data12_);
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->icon_view;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp3_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_app;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp4_, "selected-items");
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block12_data_unref (_data12_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = NULL;
#line 3239 "collection-view.c"
}


static ClutterActor* boxes_collection_view_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesCollectionView* self;
	GtkClutterActor* _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->gtkactor;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = (ClutterActor*) _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3255 "collection-view.c"
}


BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self) {
	BoxesCategory* result;
	BoxesCategory* _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_category;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3270 "collection-view.c"
}


void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value) {
	BoxesCategory* _tmp0_;
	BoxesCategory* _tmp1_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_category = _tmp1_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "category");
#line 3289 "collection-view.c"
}


void boxes_collection_view_set_visible (BoxesCollectionView* self, gboolean value) {
	GdMainIconView* _tmp0_;
	gboolean _tmp1_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->icon_view;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = value;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, _tmp1_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "visible");
#line 3306 "collection-view.c"
}


static void boxes_collection_view_class_init (BoxesCollectionViewClass * klass) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_parent_class = g_type_class_peek_parent (klass);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionViewPrivate));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_collection_view_real_ui_state_changed;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_collection_view_real_get_actor;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_view_get_property;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_view_set_property;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_view_finalize;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_CATEGORY, g_param_spec_object ("category", "category", "category", BOXES_TYPE_CATEGORY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_VISIBLE, g_param_spec_boolean ("visible", "visible", "visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 3331 "collection-view.c"
}


static void boxes_collection_view_instance_init (BoxesCollectionView * self) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv = BOXES_COLLECTION_VIEW_GET_PRIVATE (self);
#line 3338 "collection-view.c"
}


static void boxes_collection_view_finalize (GObject* obj) {
	BoxesCollectionView * self;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->gtkactor);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->icon_view);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (self->priv->button_press_item_path);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (boxes_collection_view_parent_class)->finalize (obj);
#line 3360 "collection-view.c"
}


GType boxes_collection_view_get_type (void) {
	static volatile gsize boxes_collection_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionView), 0, (GInstanceInitFunc) boxes_collection_view_instance_init, NULL };
		GType boxes_collection_view_type_id;
		boxes_collection_view_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesCollectionView", &g_define_type_info, 0);
		g_once_init_leave (&boxes_collection_view_type_id__volatile, boxes_collection_view_type_id);
	}
	return boxes_collection_view_type_id__volatile;
}


static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_ACTOR:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_collection_view_get_category (self));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3393 "collection-view.c"
		default:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3399 "collection-view.c"
	}
}


static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_category (self, g_value_get_object (value));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_VISIBLE:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_visible (self, g_value_get_boolean (value));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3421 "collection-view.c"
		default:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3427 "collection-view.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



